import { FormArray, FormGroup } from '@angular/forms';
import { ClassType } from 'class-transformer/ClassTransformer';
import { ValidatorOptions } from 'class-validator';
import 'reflect-metadata';
import { BehaviorSubject } from 'rxjs';
import { Dictionary, ShortValidationErrors } from '../models';
export declare type FormModel<T> = {
    [P in keyof T]?: T[P] | DynamicFormGroup<any> | FormArray;
};
export declare class DynamicFormGroup<TModel> extends FormGroup {
    factoryModel: ClassType<TModel>;
    defaultValidatorOptions?: ValidatorOptions;
    customValidateErrors: BehaviorSubject<ShortValidationErrors>;
    formErrors: ShortValidationErrors;
    formFields: Dictionary;
    private _object;
    private _externalErrors;
    private _validatorOptions;
    private _fb;
    constructor(factoryModel: ClassType<TModel>, fields: FormModel<TModel>, defaultValidatorOptions?: ValidatorOptions);
    externalErrors: ShortValidationErrors;
    validatorOptions: ValidatorOptions;
    object: TModel;
    validate(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): void;
    validateAsync(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): Promise<void>;
    validateAllFormFields(): void;
    classToClass<TClassModel>(object: TClassModel): TClassModel;
    plainToClass<TClassModel, Object>(cls: ClassType<TClassModel>, plain: Object): TClassModel;
    setExternalErrorsAsync(externalErrors: ShortValidationErrors): Promise<void>;
    setExternalErrors(externalErrors: ShortValidationErrors): void;
    getExternalErrors(): ShortValidationErrors;
    clearExternalErrors(): void;
    clearExternalErrorsAsync(): Promise<void>;
    setValidatorOptionsAsync(validatorOptions: ValidatorOptions): Promise<void>;
    setValidatorOptions(validatorOptions: ValidatorOptions): void;
    getValidatorOptions(): ValidatorOptions;
    private onlyFields;
    private transformValidationErrors;
    private mergeErrors;
    private markAsInvalidForExternalErrors;
    /**
     * Recursively gets all values from the form controls and all sub form group and array controls and returns it as
     * an object
     */
    private getObject;
    /**
     * Sets the value of every control on the form and recursively sets the values of the controls
     * on all sub form groups
     *
     * @param object the data to assign to all controls of the form group and sub groups
     */
    private setObject;
}
export declare function getClassValidators<TModel>(factoryModel: ClassType<TModel>, fields: Dictionary, validatorOptions?: ValidatorOptions): {};
